@@ -7,7 +7,7 @@
  * published by the Free Software Foundation; either version 2 of
  * the License or (at your option) version 3 or any later version
  * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy 
+ * by the membership of KDE e.V.), which shall act as a proxy
  * defined in Section 14 of version 3 of the license.
  *
  * This program is distributed in the hope that it will be useful,
@@ -22,6 +22,7 @@
 #include "mainWindow.h"
 #include "timeLabel.h"
 
+#include <KActionMenu>
 #include <KApplication>
 #include <KCmdLineArgs>
 #include <KCursor>
@@ -30,6 +31,7 @@
 #include <KGlobalSettings> //::timerEvent()
 #include <KIO/NetAccess>
 #include <KLocale>
+#include <KMenu>
 #include <KMenuBar>
 #include <KSqueezedTextLabel>
 #include <KStatusBar>
@@ -87,7 +89,7 @@ namespace Dragon {
 MainWindow::MainWindow()
         : KXmlGuiWindow()
         , m_mainView( 0 )
-        , m_audioView(new AudioView(this) )
+        , m_audioView( 0 )
         , m_loadView( new LoadView(this) )
         , m_currentWidget( new QWidget(this) )
         , m_leftDock( 0 )
@@ -98,8 +100,10 @@ MainWindow::MainWindow()
         , m_playDialog( 0 )
         , m_stopScreenSaver( 0 )
         , m_stopSleepCookie( -1 )
+        , m_stopScreenPowerMgmtCookie( -1 )
         , m_toolbarIsHidden(false)
         , m_statusbarIsHidden(false)
+        , m_FullScreenHandler( 0 )
 {
     s_instance = this;
     setMouseTracking( true );
@@ -111,12 +115,13 @@ MainWindow::MainWindow()
     videoWindow()->setMouseTracking( true );
 
     m_positionSlider = videoWindow()->newPositionSlider();
-    
+
     m_mainView->addWidget(m_loadView);
+    m_audioView = new AudioView(this);
     m_mainView->addWidget(m_audioView);
     m_mainView->addWidget(videoWindow());
     m_mainView->setCurrentWidget(m_loadView);
-    
+
     m_currentWidget = m_loadView;
 
     setCentralWidget( m_mainView );
@@ -131,24 +136,22 @@ MainWindow::MainWindow()
     statusBar()->setSizePolicy( QSizePolicy::Ignored, QSizePolicy::Maximum );
 
     setupActions();
-    
+
     //setStandardToolBarMenuEnabled( false ); //bah to setupGUI()!
     //toolBar()->show(); //it's possible it would be hidden, but we don't want that as no UI way to show it!
 
     {
         KActionCollection* ac = actionCollection();
-        QMenu *menu = 0;
-        QAction *menuAction = 0; 
+        KActionMenu *menuAction = 0;
         #define make_menu( name, text ) \
-                menu = new QMenu( text ); \
-                menuAction = menu->menuAction(); \
+                menuAction = new KActionMenu( text, this ); \
                 menuAction->setObjectName( name ); \
                 menuAction->setEnabled( false ); \
-                connect( menu, SIGNAL(aboutToShow()), SLOT(aboutToShowMenu()) ); \
+                connect( menuAction->menu(), SIGNAL(aboutToShow()), SLOT(aboutToShowMenu()) ); \
                 ac->addAction( menuAction->objectName(), menuAction );
-        make_menu( "aspect_ratio_menu", i18n( "Aspect &Ratio" ) );
-        make_menu( "audio_channels_menu", i18n( "&Audio Channels" ) );
-        make_menu( "subtitle_channels_menu", i18n( "&Subtitles" ) );
+        make_menu( QLatin1String( "aspect_ratio_menu" ), i18n( "Aspect &Ratio" ) );
+        make_menu( QLatin1String( "audio_channels_menu" ), i18n( "&Audio Channels" ) );
+        make_menu( QLatin1String( "subtitle_channels_menu" ), i18n( "&Subtitles" ) );
         #undef make_menu
 
         {
@@ -162,15 +165,15 @@ MainWindow::MainWindow()
                 m_aspectRatios->addAction( ratioAction ); \
                 TheStream::addRatio( aspectEnum, ratioAction ); \
                 ac->addAction( objectname, ratioAction ); \
-                connect( ratioAction, SIGNAL( triggered() ), this, SLOT( streamSettingChange() ) ); \
+                connect( ratioAction, SIGNAL(triggered()), this, SLOT(streamSettingChange()) ); \
             }
-            make_ratio_action( i18n( "Determine &Automatically" ), "ratio_auto",  Phonon::VideoWidget::AspectRatioAuto );
-            make_ratio_action( i18n( "&4:3" ), "ratio_golden", Phonon::VideoWidget::AspectRatio4_3 );
-            make_ratio_action( i18n( "Ana&morphic (16:9)" ), "ratio_anamorphic", Phonon::VideoWidget::AspectRatio16_9 );
-            make_ratio_action( i18n( "&Window Size" ), "ratio_window", Phonon::VideoWidget::AspectRatioWidget );
+            make_ratio_action( i18n( "Determine &Automatically" ), QLatin1String( "ratio_auto" ),  Phonon::VideoWidget::AspectRatioAuto );
+            make_ratio_action( i18n( "&4:3" ), QLatin1String( "ratio_golden" ), Phonon::VideoWidget::AspectRatio4_3 );
+            make_ratio_action( i18n( "Ana&morphic (16:9)" ), QLatin1String( "ratio_anamorphic" ), Phonon::VideoWidget::AspectRatio16_9 );
+            make_ratio_action( i18n( "&Window Size" ), QLatin1String( "ratio_window" ), Phonon::VideoWidget::AspectRatioWidget );
             #undef make_ratio_action
-            ac->action( "ratio_auto" )->setChecked( true );
-            ac->action( "aspect_ratio_menu" )->menu()->addActions( m_aspectRatios->actions() );
+            ac->action( QLatin1String( "ratio_auto" ) )->setChecked( true );
+            ac->action( QLatin1String( "aspect_ratio_menu" ) )->menu()->addActions( m_aspectRatios->actions() );
         }
     }
 
@@ -180,18 +183,18 @@ MainWindow::MainWindow()
         toolBar()->setAllowedAreas( Qt::TopToolBarArea | Qt::BottomToolBarArea );
         toolBar()->setFloatable( false );
     }
-    KXMLGUIClient::stateChanged( "empty" );
+    KXMLGUIClient::stateChanged( QLatin1String( "empty" ) );
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
     if( args->count() || args->isSet( "play-dvd" ) || kapp->isSessionRestored() )
         //we need to resize the window, so we can't show the window yet
         init();
-    else 
+    else
     {
         //"faster" startup
         //TODO if we have a size stored for this video, do the "faster" route
         QTimer::singleShot( 0, this, SLOT(init()) );
-        QApplication::setOverrideCursor( Qt::WaitCursor ); 
+        QApplication::setOverrideCursor( Qt::WaitCursor );
     }
 }
 
@@ -204,30 +207,29 @@ MainWindow::init()
     connect( m_loadView, SIGNAL(loadUrl(KUrl)), this, SLOT(open(KUrl)) );
 
     //connect the video player
-    connect( engine(), SIGNAL( stateUpdated( Phonon::State, Phonon::State ) ), this, SLOT( engineStateChanged( Phonon::State, Phonon::State ) ) );
-    connect( engine(), SIGNAL( currentSourceChanged( Phonon::MediaSource ) ), this, SLOT( engineMediaChanged( Phonon::MediaSource ) ) );
-    connect( engine(), SIGNAL( seekableChanged( bool ) ), this, SLOT( engineSeekableChanged( bool ) ) );
-    connect( engine(), SIGNAL( metaDataChanged() ), this, SLOT( engineMetaDataChanged() ) );
-    connect( engine(), SIGNAL( hasVideoChanged( bool ) ), this, SLOT( engineHasVideoChanged( bool ) ) );
+    connect( engine(), SIGNAL(stateUpdated(Phonon::State,Phonon::State)), this, SLOT(engineStateChanged(Phonon::State,Phonon::State)) );
+    connect( engine(), SIGNAL(currentSourceChanged(Phonon::MediaSource)), this, SLOT(engineMediaChanged(Phonon::MediaSource)) );
+    connect( engine(), SIGNAL(seekableChanged(bool)), this, SLOT(engineSeekableChanged(bool)) );
+    connect( engine(), SIGNAL(metaDataChanged()), this, SLOT(engineMetaDataChanged()) );
+    connect( engine(), SIGNAL(hasVideoChanged(bool)), this, SLOT(engineHasVideoChanged(bool)) );
 
-    connect( engine(), SIGNAL( subChannelsChanged( QList< QAction* > ) ), this, SLOT( subChannelsChanged( QList< QAction* > ) ) );
-    connect( engine(), SIGNAL( audioChannelsChanged( QList< QAction* > ) ), this, SLOT( audioChannelsChanged( QList< QAction* > ) ) );
-    connect( engine(), SIGNAL( mutedChanged( bool ) ), this, SLOT( mutedChanged( bool ) ) );
+    connect( engine(), SIGNAL(subChannelsChanged(QList<QAction*>)), this, SLOT(subChannelsChanged(QList<QAction*>)) );
+    connect( engine(), SIGNAL(audioChannelsChanged(QList<QAction*>)), this, SLOT(audioChannelsChanged(QList<QAction*>)) );
+    connect( engine(), SIGNAL(mutedChanged(bool)), this, SLOT(mutedChanged(bool)) );
 
     if( !engine()->init() ) {
         KMessageBox::error( this, i18n(
-            "<qt>xine could not be successfully initialised. Dragon Player will now exit. "
-            "You can try to identify what is wrong with your xine installation using the <b>xine-check</b> command at a command-prompt.</qt>") );
+            "<qt>Phonon could not be successfully initialized. Dragon Player will now exit.</qt>") );
         QApplication::exit( 2 );
     }
 
     //would be dangerous for these to65535 happen before the videoWindow() is initialised
     setAcceptDrops( true );
-    connect( statusBar(), SIGNAL(messageChanged( const QString& )), engine(), SLOT(showOSD( const QString& )) );
+    connect( statusBar(), SIGNAL(messageChanged(QString)), engine(), SLOT(showOSD(QString)) );
     //statusBar()->insertPermanentItem( "hello world", 0, 0 );
     m_timeLabel = new TimeLabel( statusBar() );
-    connect( videoWindow(), SIGNAL( tick( qint64) ), m_timeLabel, SLOT( setCurrentTime( qint64 ) ) );
-    connect( videoWindow(), SIGNAL( totalTimeChanged( qint64 ) ), m_timeLabel, SLOT( setTotalTime( qint64 ) ) );
+    connect( videoWindow(), SIGNAL(tick(qint64)), m_timeLabel, SLOT(setCurrentTime(qint64)) );
+    connect( videoWindow(), SIGNAL(totalTimeChanged(qint64)), m_timeLabel, SLOT(setTotalTime(qint64)) );
     statusBar()->addPermanentWidget( m_titleLabel, 100 );
     statusBar()->addPermanentWidget( m_timeLabel );
 
@@ -268,7 +270,7 @@ void MainWindow::closeEvent (QCloseEvent *event)
     statusBar()->setHidden( m_statusbarIsHidden );
     toolBar()->setHidden( m_toolbarIsHidden );
     menuBar()->setHidden( false );
-    
+
     KMainWindow::closeEvent( event );
 }
 
@@ -288,93 +290,93 @@ MainWindow::setupActions()
 
     KActionCollection * const ac = actionCollection();
 
-    KStandardAction::quit( kapp, SLOT( closeAllWindows() ), ac );
+    KStandardAction::quit( kapp, SLOT(closeAllWindows()), ac );
 
     KStandardAction::open( this, SLOT(toggleLoadView()), ac )->setText( i18n("Play &Media...") );
 
     #define addToAc( X ) ac->addAction( X->objectName(), X );
 
     KToggleFullScreenAction* toggleFullScreen = new KToggleFullScreenAction( this, ac );
-    toggleFullScreen->setObjectName( "fullscreen" );
+    toggleFullScreen->setObjectName( QLatin1String( "fullscreen" ) );
     toggleFullScreen->setShortcut( Qt::Key_F );
     toggleFullScreen->setAutoRepeat( false );
-    connect( toggleFullScreen, SIGNAL( toggled( bool ) ), Dragon::mainWindow(), SLOT( setFullScreen( bool ) ) );
+    connect( toggleFullScreen, SIGNAL(toggled(bool)), Dragon::mainWindow(), SLOT(setFullScreen(bool)) );
     addToAc( toggleFullScreen );
 
-    new PlayAction( this, SLOT( play() ), ac );
-    new VolumeAction( this, SLOT( toggleVolumeSlider( bool ) ), ac );
+    new PlayAction( this, SLOT(play()), ac );
+    new VolumeAction( this, SLOT(toggleVolumeSlider(bool)), ac );
 
-    KAction* playerStop = new KAction( KIcon("media-playback-stop"), i18n("Stop"), ac );
-    playerStop->setObjectName( "stop" );
+    KAction* playerStop = new KAction( KIcon(QLatin1String( "media-playback-stop" )), i18n("Stop"), ac );
+    playerStop->setObjectName( QLatin1String( "stop" ) );
     playerStop->setShortcut( Qt::Key_S );
-    connect( playerStop, SIGNAL( triggered() ), engine(), SLOT( stop() ) );
+    connect( playerStop, SIGNAL(triggered()), engine(), SLOT(stop()) );
     addToAc( playerStop )
 
-    KToggleAction* mute = new KToggleAction( KIcon("player-volume-muted"), i18nc( "Mute the sound output", "Mute"), ac );
-    mute->setObjectName( "mute" );
+    KToggleAction* mute = new KToggleAction( KIcon(QLatin1String( "player-volume-muted" )), i18nc( "Mute the sound output", "Mute"), ac );
+    mute->setObjectName( QLatin1String( "mute" ) );
     mute->setShortcut( Qt::Key_M );
-    connect( mute, SIGNAL( toggled( bool ) ), videoWindow(), SLOT( mute( bool ) ) );
+    connect( mute, SIGNAL(toggled(bool)), videoWindow(), SLOT(mute(bool)) );
     addToAc( mute )
 
-    KAction* resetZoom = new KAction( KIcon("zoom-fit-best"), i18n("Reset Video Scale"), ac );
-    resetZoom->setObjectName( "reset_zoom" );
+    KAction* resetZoom = new KAction( KIcon(QLatin1String( "zoom-fit-best" )), i18n("Reset Video Scale"), ac );
+    resetZoom->setObjectName( QLatin1String( "reset_zoom" ) );
     resetZoom->setShortcut( Qt::Key_Equal );
-    connect( resetZoom, SIGNAL( triggered() ), videoWindow(), SLOT( resetZoom() ) );
+    connect( resetZoom, SIGNAL(triggered()), videoWindow(), SLOT(resetZoom()) );
     addToAc( resetZoom )
 
-    KAction* dvdMenu = new KAction( KIcon("media-optical-video"), i18n("Menu Toggle"), ac );
-    dvdMenu->setObjectName( "toggle_dvd_menu" );
+    KAction* dvdMenu = new KAction( KIcon(QLatin1String( "media-optical-video" )), i18n("Menu Toggle"), ac );
+    dvdMenu->setObjectName( QLatin1String( "toggle_dvd_menu" ) );
     dvdMenu->setShortcut( Qt::Key_R );
-    connect( dvdMenu, SIGNAL( triggered() ), engine(), SLOT( toggleDVDMenu() ) );
+    connect( dvdMenu, SIGNAL(triggered()), engine(), SLOT(toggleDVDMenu()) );
     addToAc( dvdMenu )
 
     KAction* positionSlider = new KAction( i18n("Position Slider"), ac );
-    positionSlider->setObjectName( "position_slider" );
+    positionSlider->setObjectName( QLatin1String( "position_slider" ) );
     positionSlider->setDefaultWidget( m_positionSlider );
     addToAc( positionSlider )
 
     KAction* videoSettings = new KAction( i18n("Video Settings"), ac );
-    videoSettings->setObjectName( "video_settings" );
+    videoSettings->setObjectName( QLatin1String( "video_settings" ) );
     videoSettings->setCheckable( true );
-    connect( videoSettings, SIGNAL( toggled( bool ) ), this, SLOT( toggleVideoSettings( bool ) ) );
+    connect( videoSettings, SIGNAL(toggled(bool)), this, SLOT(toggleVideoSettings(bool)) );
     addToAc( videoSettings )
 
-    KAction* prev_chapter = new KAction( KIcon("media-skip-backward"), i18n("Previous Chapter"), ac );
-    prev_chapter->setObjectName( "prev_chapter" );
+    KAction* prev_chapter = new KAction( KIcon(QLatin1String( "media-skip-backward" )), i18n("Previous Chapter"), ac );
+    prev_chapter->setObjectName( QLatin1String( "prev_chapter" ) );
     prev_chapter->setShortcut( Qt::Key_Comma );
-    connect( prev_chapter, SIGNAL( triggered() ), engine(), SLOT( prevChapter() ) );
+    connect( prev_chapter, SIGNAL(triggered()), engine(), SLOT(prevChapter()) );
     addToAc( prev_chapter )
 
-    KAction* next_chapter = new KAction( KIcon("media-skip-forward"), i18n("Next Chapter"), ac );
-    next_chapter->setObjectName( "next_chapter" );
+    KAction* next_chapter = new KAction( KIcon(QLatin1String( "media-skip-forward" )), i18n("Next Chapter"), ac );
+    next_chapter->setObjectName( QLatin1String( "next_chapter" ) );
     next_chapter->setShortcut( Qt::Key_Period );
-    connect( next_chapter, SIGNAL( triggered() ), engine(), SLOT( nextChapter() ) );
+    connect( next_chapter, SIGNAL(triggered()), engine(), SLOT(nextChapter()) );
     addToAc( next_chapter )
 
     // xgettext: no-c-format
-    KAction* tenPercentBack = new KAction( KIcon("media-seek-backward"), i18n("Return 10% Back"), ac );
-    tenPercentBack->setObjectName( "ten_percent_back" );
+    KAction* tenPercentBack = new KAction( KIcon(QLatin1String( "media-seek-backward" )), i18n("Return 10% Back"), ac );
+    tenPercentBack->setObjectName( QLatin1String( "ten_percent_back" ) );
     tenPercentBack->setShortcut( Qt::Key_PageUp );
-    connect( tenPercentBack, SIGNAL( triggered() ), engine(), SLOT( tenPercentBack() ) );
+    connect( tenPercentBack, SIGNAL(triggered()), engine(), SLOT(tenPercentBack()) );
     addToAc( tenPercentBack )
 
     // xgettext: no-c-format
-    KAction* tenPercentForward = new KAction( KIcon("media-seek-forward"), i18n("Go 10% Forward"), ac );
-    tenPercentForward->setObjectName( "ten_percent_forward" );
+    KAction* tenPercentForward = new KAction( KIcon(QLatin1String( "media-seek-forward" )), i18n("Go 10% Forward"), ac );
+    tenPercentForward->setObjectName( QLatin1String( "ten_percent_forward" ) );
     tenPercentForward->setShortcut( Qt::Key_PageDown );
-    connect( tenPercentForward, SIGNAL( triggered() ), engine(), SLOT( tenPercentForward() ) );
+    connect( tenPercentForward, SIGNAL(triggered()), engine(), SLOT(tenPercentForward()) );
     addToAc( tenPercentForward )
 
-    KAction* tenSecondsBack = new KAction( KIcon("media-seek-backward"), i18n("Return 10 Seconds Back"), ac );
-    tenSecondsBack->setObjectName( "ten_seconds_back" );
+    KAction* tenSecondsBack = new KAction( KIcon(QLatin1String( "media-seek-backward" )), i18n("Return 10 Seconds Back"), ac );
+    tenSecondsBack->setObjectName( QLatin1String( "ten_seconds_back" ) );
     tenSecondsBack->setShortcut( Qt::Key_Minus );
-    connect( tenSecondsBack, SIGNAL( triggered() ), engine(), SLOT( tenSecondsBack() ) );
+    connect( tenSecondsBack, SIGNAL(triggered()), engine(), SLOT(tenSecondsBack()) );
     addToAc( tenSecondsBack )
 
-    KAction* tenSecondsForward = new KAction( KIcon("media-seek-forward"), i18n("Go 10 Seconds Forward"), ac );
-    tenSecondsForward->setObjectName( "ten_seconds_forward" );
+    KAction* tenSecondsForward = new KAction( KIcon(QLatin1String( "media-seek-forward" )), i18n("Go 10 Seconds Forward"), ac );
+    tenSecondsForward->setObjectName( QLatin1String( "ten_seconds_forward" ) );
     tenSecondsForward->setShortcut( Qt::Key_Plus );
-    connect( tenSecondsForward, SIGNAL( triggered() ), engine(), SLOT( tenSecondsForward() ) );
+    connect( tenSecondsForward, SIGNAL(triggered()), engine(), SLOT(tenSecondsForward()) );
     addToAc( tenSecondsForward )
     #undef addToAc
 }
@@ -385,7 +387,7 @@ MainWindow::toggleVideoSettings( bool show )
     if( show )
     {
         m_leftDock = new QDockWidget( this );
-        m_leftDock->setObjectName("left_dock");
+        m_leftDock->setObjectName( QLatin1String("left_dock" ));
         m_leftDock->setFeatures( QDockWidget::NoDockWidgetFeatures );
         QWidget* videoSettingsWidget = new QWidget( m_leftDock );
         m_leftDock->setWidget( videoSettingsWidget );
@@ -397,11 +399,11 @@ MainWindow::toggleVideoSettings( bool show )
         m_sliders << ui.brightnessSlider << ui.contrastSlider << ui.hueSlider <<  ui.saturationSlider;
         updateSliders();
         foreach( QSlider* slider, m_sliders )
-             connect( slider, SIGNAL( valueChanged( int ) ), engine(), SLOT( settingChanged( int ) ) );
-        
-        connect( ui.defaultsButton, SIGNAL( clicked( bool ) ), this, SLOT( restoreDefaultVideoSettings() ) );
-        connect( ui.closeButton, SIGNAL( clicked( bool ) ), action( "video_settings" ), SLOT( setChecked( bool ) ) );
-        connect( ui.closeButton, SIGNAL( clicked( bool ) ), m_leftDock, SLOT( deleteLater() ) );
+             connect( slider, SIGNAL(valueChanged(int)), engine(), SLOT(settingChanged(int)) );
+
+        connect( ui.defaultsButton, SIGNAL(clicked(bool)), this, SLOT(restoreDefaultVideoSettings()) );
+        connect( ui.closeButton, SIGNAL(clicked(bool)), action( "video_settings" ), SLOT(setChecked(bool)) );
+        connect( ui.closeButton, SIGNAL(clicked(bool)), m_leftDock, SLOT(deleteLater()) );
     }
     else
     {
@@ -442,7 +444,7 @@ MainWindow::toggleLoadView()
       engine()->isPreview(true);
       m_loadView->setThumbnail(m_currentWidget);
     }
-    else 
+    else
     {
       m_mainView->setCurrentWidget(m_loadView);
     }
@@ -459,7 +461,7 @@ MainWindow::toggleVolumeSlider( bool show )
         m_muteCheckBox = new QCheckBox();
         m_muteCheckBox->setText( i18nc( "Mute the sound output", "Mute " ) );
         m_muteCheckBox->setChecked ( engine()->isMuted() );
-        connect( m_muteCheckBox, SIGNAL( toggled( bool ) ), videoWindow(), SLOT( mute( bool ) ) );
+        connect( m_muteCheckBox, SIGNAL(toggled(bool)), videoWindow(), SLOT(mute(bool)) );
 
         QVBoxLayout *layout = new QVBoxLayout();
         layout->addWidget(m_volumeSlider);
@@ -476,8 +478,8 @@ MainWindow::toggleVolumeSlider( bool show )
     }
     else
     {
-        disconnect( m_muteCheckBox, SIGNAL( toggled( bool ) ), videoWindow(), SLOT( mute( bool ) ) );
-        delete m_rightDock;
+        disconnect( m_muteCheckBox, SIGNAL(toggled(bool)), videoWindow(), SLOT(mute(bool)) );
+        delete m_rightDock; // it's a QPointer, it will 0 itself
     }
 }
 
@@ -517,11 +519,6 @@ MainWindow::open( const KUrl &url )
         kDebug() << "Initial offset is "<< offset;
         engine()->loadSettings();
         updateSliders();
-        if( TheStream::hasVideo() )
-          m_currentWidget = engine();
-        else
-          m_currentWidget = m_audioView;
-        m_mainView->setCurrentWidget(m_currentWidget);
         return engine()->play( offset );
     }
 
@@ -568,7 +565,16 @@ MainWindow::load( const KUrl &url )
 
     //let xine handle invalid, etc, KUrlS
     //TODO it handles non-existing files with bad error message
-    return engine()->load( url );
+    bool ret = engine()->load( url );
+    if( ret )
+    {
+        if( TheStream::hasVideo() )
+            m_currentWidget = engine();
+        else
+            m_currentWidget = m_audioView;
+        m_mainView->setCurrentWidget(m_currentWidget);
+    }
+    return ret;
 }
 
 void
@@ -589,7 +595,7 @@ MainWindow::play()
         else
           m_currentWidget = m_audioView;
         engine()->play();
-        m_mainView->setCurrentWidget(engine());
+        m_mainView->setCurrentWidget(m_currentWidget);
         break;
     default:
         break;
@@ -599,13 +605,14 @@ MainWindow::play()
 void
 MainWindow::openFileDialog()
 {
-       QStringList mimeFilter=Phonon::BackendCapabilities::availableMimeTypes();
+       QStringList mimeFilter = Phonon::BackendCapabilities::availableMimeTypes();
         //temporary fixes for MimeTypes that Xine does support but it doesn't return - this is a Xine bug.
-        mimeFilter << "audio/x-flac";
-        mimeFilter << "video/mp4";
-        mimeFilter << "application/x-cd-image"; // added for *.iso images
+        mimeFilter << QLatin1String( "audio/x-flac");
+        mimeFilter << QLatin1String( "video/mp4" );
+        mimeFilter << QLatin1String( "application/x-cd-image" ); // added for *.iso images
 
-        const KUrl url = KFileDialog::getOpenUrl( KUrl("kfiledialog:///dragonplayer"),mimeFilter.join(" "), this, i18n("Select File to Play") );
+        const KUrl url = KFileDialog::getOpenUrl( KUrl("kfiledialog:///dragonplayer"),mimeFilter.join(QLatin1String( " " ))
+                                        , this, i18n("Select File to Play") );
         if( url.isEmpty() )
         {
             kDebug() << "URL empty in MainWindow::playDialogResult()";
@@ -623,7 +630,7 @@ MainWindow::playDisc()
     QList< Solid::Device > playableDiscs;
     {
         QList< Solid::Device > deviceList = Solid::Device::listFromType( Solid::DeviceInterface::OpticalDisc );
-        
+
         foreach( const Solid::Device &device, deviceList )
         {
             const Solid::OpticalDisc* disc = device.as<const Solid::OpticalDisc>();
@@ -631,7 +638,7 @@ MainWindow::playDisc()
             {
                 if( disc->availableContent() & ( Solid::OpticalDisc::VideoDvd | Solid::OpticalDisc::VideoCd | Solid::OpticalDisc::SuperVideoCd |  Solid::OpticalDisc::Audio ) )
                     playableDiscs << device;
-            
+
             }
         }
     }
@@ -644,11 +651,15 @@ MainWindow::playDisc()
         }
         else //only one optical disc inserted, play whatever it is
         {
-            kDebug() << "playing disc", engine()->playDisc( playableDiscs.first() );
+            bool status = engine()->playDisc( playableDiscs.first() );
+            kDebug() << "playing disc" << status ;
         }
     }
     else
-        engine()->playDvd(); kDebug() << "no disc in drive or Solid isn't working";
+    {
+        engine()->playDvd();
+        kDebug() << "no disc in drive or Solid isn't working";
+    }
 
 }
 
@@ -665,7 +676,6 @@ MainWindow::setFullScreen( bool isFullScreen )
 {
     kDebug() << "Setting full screen to " << isFullScreen;
     mainWindow()->setWindowState( (isFullScreen ? Qt::WindowFullScreen : Qt::WindowNoState ));
-    static FullScreenToolBarHandler *s_handler;
 
 	if(isFullScreen)
 	{
@@ -682,15 +692,17 @@ MainWindow::setFullScreen( bool isFullScreen )
     menuBar()->setHidden( isFullScreen );
     if( m_leftDock )
         m_leftDock->setHidden( isFullScreen );
-    if( m_rightDock )
-        m_rightDock->setHidden( isFullScreen );
+    // the right dock is handled by the tool bar handler
 
-    if( isFullScreen )
-        s_handler = new FullScreenToolBarHandler( this );
+    if( isFullScreen ) {
+        if (!m_FullScreenHandler)
+            m_FullScreenHandler = new FullScreenToolBarHandler( this );
+    }
     else
     {
         action( "fullscreen" )->setEnabled( videoWindow()->state() ==  Phonon::PlayingState || videoWindow()->state() ==  Phonon::PausedState);
-        delete s_handler;
+        delete m_FullScreenHandler;
+        m_FullScreenHandler = 0;
     }
 }
 
@@ -701,6 +713,14 @@ MainWindow::showVolume( bool visible)
         m_rightDock->setVisible( visible );
 }
 
+bool
+MainWindow::volumeContains( QPoint mousePos )
+{
+    if ( m_rightDock )
+        return m_rightDock->geometry().contains(mousePos);
+    return false;
+}
+
 void
 MainWindow::aboutToShowMenu()
 {
@@ -769,13 +789,13 @@ QMenu*
 MainWindow::menu( const char *name )
 {
     // KXMLGUI is "really good".
-    return static_cast<QMenu*>(factory()->container( name, this ));
+    return static_cast<QMenu*>(factory()->container( QLatin1String( name ), this ));
 }
 
-void 
+void
 MainWindow::streamSettingChange()
 {
-    if( sender()->objectName().left( 5 ) == "ratio" )
+    if( sender()->objectName().left( 5 ) == QLatin1String( "ratio" ) )
     {
         TheStream::setRatio( dynamic_cast< QAction* > ( sender() ) );
     }
@@ -832,7 +852,7 @@ action( const char *name )
 
     if( mainWindow() )
         if( ( actionCollection = ((MainWindow*)mainWindow() )->actionCollection() ) )
-            action = actionCollection->action( name );
+            action = actionCollection->action(QLatin1String( name ) );
     if( !action )
         kDebug() << name;
     Q_ASSERT( mainWindow() );
