@@ -29,7 +29,6 @@
 
 #include <Phonon/Path>
 #include <Phonon/MediaSource>
-
 #include <Phonon/ObjectDescription>
 #include <Solid/Device>
 #include <KUrl>
@@ -42,10 +41,9 @@ namespace Phonon {
      class AudioOutput;
      class MediaObject;
      class MediaController;
+     class AudioDataOutput;
 }
 
-typedef struct xine_stream_s xine_stream_t;
-
 #include "phonon/phononnamespace.h" //Phonon::State
 
 namespace Dragon
@@ -65,7 +63,6 @@ namespace Dragon
         QTimer* m_cursorTimer;
         bool m_justLoaded;
 		bool m_adjustedSize;
-        xine_stream_t* m_xineStream;
         QActionGroup* m_subLanguages;
         QActionGroup* m_audioLanguages;
         QWidget* m_logo;
@@ -75,7 +72,9 @@ namespace Dragon
         Phonon::AudioOutput *m_aOutput;
         Phonon::MediaObject *m_media;
         Phonon::MediaController *m_controller;
+        Phonon::AudioDataOutput* m_aDataOutput;
         Phonon::Path m_audioPath;
+        Phonon::Path m_audioDataPath;
 
         friend class TheStream;
 
@@ -95,16 +94,15 @@ namespace Dragon
         bool playDvd();
         bool playDisc( const Solid::Device& );
         bool isMuted();
-        bool mouseUnderWidget();
         bool isPreview(const bool &v = 0);
         void relativeSeek( qint64 );
 
         qint64 length() const;
         bool isDVD() const;
 
+        bool setupAnalyzer(QObject* analzyer); ///return whether setup was successful
+        
         ///stuff for dbus:
-        //{
-
         qreal volume() const;
         void setVolume( qreal );
         QString urlOrDisc() const;
@@ -128,8 +126,6 @@ namespace Dragon
         qint64 currentTime() const;
         int videoSetting( const QString& );
 
-        const xine_stream_t* xineStream() const { return m_xineStream; }
-
     public slots:
         void pause();
         void playPause();
@@ -157,7 +153,6 @@ namespace Dragon
         virtual void contextMenuEvent( QContextMenuEvent * event );
         virtual void mouseDoubleClickEvent( QMouseEvent* );
         virtual QSize sizeHint() const;
-        void refreshXineStream();
         Phonon::State state( Phonon::State state ) const;
         void setSubtitle( int channel );
         void setAudioChannel( int channel );
