@@ -2,7 +2,7 @@
     begin                : Thu Oct 28 2004
     copyright            : (C) 2004, 2007, 2009 by Michael Pyne
                          : (c) 2003 Frerich Raabe <raabe@kde.org>
-    email                : michael.pyne@kdemail.net
+    email                : mpyne@kde.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -61,7 +61,7 @@ public:
                        QWidget *parent = 0, const char *name = 0)
         : KDialog(parent)
     {
-        setObjectName(name);
+        setObjectName( QLatin1String( name ) );
         setModal(true);
         setCaption(i18nc("warning about mass file rename", "Warning"));
         setButtons(Ok | Cancel);
@@ -252,8 +252,8 @@ FileRenamerWidget::FileRenamerWidget(QWidget *parent) :
     connect(m_exampleDialog, SIGNAL(signalShown()), SLOT(exampleDialogShown()));
     connect(m_exampleDialog, SIGNAL(signalHidden()), SLOT(exampleDialogHidden()));
     connect(m_exampleDialog, SIGNAL(dataChanged()), SLOT(dataSelected()));
-    connect(m_exampleDialog, SIGNAL(fileChanged(const QString &)),
-            this,            SLOT(fileSelected(const QString &)));
+    connect(m_exampleDialog, SIGNAL(fileChanged(QString)),
+            this,            SLOT(fileSelected(QString)));
 
     exampleTextChanged();
 }
@@ -274,7 +274,10 @@ void FileRenamerWidget::loadConfig()
     }
 
     QString path = config.readEntry("MusicFolder", "${HOME}/music");
-    m_ui->m_musicFolder->setPath(path);
+    m_ui->m_musicFolder->setUrl(KUrl(path));
+    m_ui->m_musicFolder->setMode(KFile::Directory |
+                                 KFile::ExistingOnly |
+                                 KFile::LocalOnly);
 
     m_ui->m_separator->setEditText(config.readEntry("Separator", " - "));
 }
@@ -492,13 +495,13 @@ void FileRenamerWidget::createTagRows()
     m_folderSwitches.reserve(categoryOrder.count() - 1);
 
     mapper       = new QSignalMapper(this);
-    mapper->setObjectName("signal mapper");
+    mapper->setObjectName( QLatin1String("signal mapper" ));
     toggleMapper = new QSignalMapper(this);
-    toggleMapper->setObjectName("toggle mapper");
+    toggleMapper->setObjectName( QLatin1String("toggle mapper" ));
     upMapper     = new QSignalMapper(this);
-    upMapper->setObjectName("up button mapper");
+    upMapper->setObjectName( QLatin1String("up button mapper" ));
     downMapper   = new QSignalMapper(this);
-    downMapper->setObjectName("down button mapper");
+    downMapper->setObjectName( QLatin1String("down button mapper" ));
 
     connect(mapper,       SIGNAL(mapped(int)), SLOT(showCategoryOption(int)));
     connect(toggleMapper, SIGNAL(mapped(int)), SLOT(slotRemoveRow(int)));
@@ -775,8 +778,8 @@ void FileRenamerWidget::toggleExampleDialog()
 
 void FileRenamerWidget::insertCategory()
 {
-    TagType category = TagRenamerOptions::tagFromCategoryText(m_ui->m_category->currentText());
-    if(category == Unknown) {
+    TagType category = static_cast<TagType>(m_ui->m_category->currentIndex());
+    if(m_ui->m_category->currentIndex() < 0 || category >= NumTypes) {
         kError() << "Trying to add unknown category somehow.\n";
         return;
     }
@@ -949,7 +952,7 @@ void FileRenamer::setFolderIcon(const KUrl &dst, const PlaylistItem *item)
 
     // Split path, and go through each path element.  If a path element has
     // the album information, set its folder icon.
-    QStringList elements = dstURL.directory().split("/", QString::SkipEmptyParts);
+    QStringList elements = dstURL.directory().split('/', QString::SkipEmptyParts);
     QString path;
 
     for(QStringList::ConstIterator it = elements.constBegin(); it != elements.constEnd(); ++it) {
