@@ -38,7 +38,6 @@ class JuK : public KXmlGuiWindow
 public:
     JuK(QWidget* parent = 0);
     virtual ~JuK();
-    virtual KActionCollection *actionCollection() const;
 
     static JuK* JuKInstance();
 
@@ -70,7 +69,6 @@ private slots:
     void slotShowHide();
     void slotAboutToQuit();
     void slotQuit();
-    void slotPlaybackStopped();
     void slotToggleSystemTray(bool enabled);
     void slotEditKeys();
     void slotConfigureTagGuesser();
@@ -84,7 +82,6 @@ private:
     StatusLabel *m_statusLabel;
     SystemTray *m_systemTray;
 
-    SliderAction *m_sliderAction;
     KToggleAction *m_randomPlayAction;
     KToggleAction *m_toggleSystemTrayAction;
     KToggleAction *m_toggleDockOnCloseAction;
