@@ -381,7 +381,7 @@ Playlist::Playlist(PlaylistCollection *collection, const QFileInfo &playlistFile
     m_widthsDirty(true),
     m_searchEnabled(true),
     m_lastSelected(0),
-    m_fileName(playlistFile.absoluteFilePath()),
+    m_fileName(playlistFile.canonicalFilePath()),
     m_rmbMenu(0),
     m_toolTip(0),
     m_blockDataChanged(false)
@@ -1078,7 +1078,7 @@ void Playlist::decode(const QMimeData *s, PlaylistItem *item)
 
         KMimeType::Ptr mimeType = KMimeType::findByPath(file);
 
-        if(item && mimeType->name().startsWith("image/")) {
+        if(item && mimeType->name().startsWith(QLatin1String("image/"))) {
             item->file().coverInfo()->setCover(QImage(file));
             refreshAlbum(item->file().tag()->artist(),
                          item->file().tag()->album());
@@ -1251,8 +1251,6 @@ void Playlist::applySharedSettings()
 
 void Playlist::read(QDataStream &s)
 {
-    QString buffer;
-
     s >> m_playlistName
       >> m_fileName;
 
@@ -1260,6 +1258,9 @@ void Playlist::read(QDataStream &s)
     if(m_playlistName.isEmpty())
         throw BICStreamException();
 
+    // Do not sort. Add the files in the order they were saved.
+    setSorting(columns() + 1);
+
     QStringList files;
     s >> files;
 
@@ -1325,8 +1326,9 @@ void Playlist::takeItem(Q3ListViewItem *item)
 
 int Playlist::addColumn(const QString &label, int)
 {
-    slotWeightDirty(columns());
-    return K3ListView::addColumn(label, 30);
+    int newIndex = K3ListView::addColumn(label, 30);
+    slotWeightDirty(newIndex);
+    return newIndex;
 }
 
 PlaylistItem *Playlist::createItem(const FileHandle &file,
@@ -1550,7 +1552,7 @@ void Playlist::slotInitialize()
     QAction *showAction;
 
     for(int i = 0; i < header()->count(); ++i) {
-        if(i == PlaylistItem::FileNameColumn)
+        if(i - columnOffset() == PlaylistItem::FileNameColumn)
             m_headerMenu->addSeparator();
 
         showAction = new QAction(header()->label(i), m_headerMenu);
@@ -1562,19 +1564,19 @@ void Playlist::slotInitialize()
         adjustColumn(i);
     }
 
-    connect(m_headerMenu, SIGNAL(triggered(QAction *)), this, SLOT(slotToggleColumnVisible(QAction *)));
+    connect(m_headerMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotToggleColumnVisible(QAction*)));
 
-    connect(this, SIGNAL(contextMenuRequested(Q3ListViewItem *, const QPoint &, int)),
-            this, SLOT(slotShowRMBMenu(Q3ListViewItem *, const QPoint &, int)));
-    connect(this, SIGNAL(itemRenamed(Q3ListViewItem *, const QString &, int)),
-            this, SLOT(slotInlineEditDone(Q3ListViewItem *, const QString &, int)));
-    connect(this, SIGNAL(doubleClicked(Q3ListViewItem *)),
+    connect(this, SIGNAL(contextMenuRequested(Q3ListViewItem*,QPoint,int)),
+            this, SLOT(slotShowRMBMenu(Q3ListViewItem*,QPoint,int)));
+    connect(this, SIGNAL(itemRenamed(Q3ListViewItem*,QString,int)),
+            this, SLOT(slotInlineEditDone(Q3ListViewItem*,QString,int)));
+    connect(this, SIGNAL(doubleClicked(Q3ListViewItem*)),
             this, SLOT(slotPlayCurrent()));
-    connect(this, SIGNAL(returnPressed(Q3ListViewItem *)),
+    connect(this, SIGNAL(returnPressed(Q3ListViewItem*)),
             this, SLOT(slotPlayCurrent()));
 
-    connect(header(), SIGNAL(sizeChange(int, int, int)),
-            this, SLOT(slotColumnSizeChanged(int, int, int)));
+    connect(header(), SIGNAL(sizeChange(int,int,int)),
+            this, SLOT(slotColumnSizeChanged(int,int,int)));
 
     connect(renameLineEdit(), SIGNAL(completionModeChanged(KGlobalSettings::Completion)),
             this, SLOT(slotInlineCompletionModeChanged(KGlobalSettings::Completion)));
@@ -1623,17 +1625,7 @@ CollectionListItem *Playlist::collectionListItem(const FileHandle &file)
     CollectionListItem *item = CollectionList::instance()->lookup(file.absFilePath());
 
     if(!item) {
-        item = new CollectionListItem(file);
-        setupItem(item);
-
-        // If a valid tag was not created, destroy the CollectionListItem.
-
-        if(!item->isValid()) {
-            kError() << "Playlist::createItem() -- A valid tag was not created for \""
-                           << file.absFilePath() << "\"" << endl;
-            delete item;
-            return 0;
-        }
+        item = CollectionList::instance()->createItem(file);
     }
 
     return item;
@@ -1686,7 +1678,7 @@ void Playlist::setup()
 {
     setItemMargin(3);
 
-    connect(header(), SIGNAL(indexChange(int, int, int)), this, SLOT(slotColumnOrderChanged(int, int, int)));
+    connect(header(), SIGNAL(indexChange(int,int,int)), this, SLOT(slotColumnOrderChanged(int,int,int)));
 
     connect(m_fetcher, SIGNAL(signalCoverChanged(int)), this, SLOT(slotCoverChanged(int)));
 
@@ -1704,7 +1696,10 @@ void Playlist::setup()
     m_headerMenu = m_columnVisibleAction->menu();
 
     // TODO: Determine if other stuff in setup must happen before slotInitialize().
-    QTimer::singleShot(0, this, SLOT(slotInitialize()));
+
+    // Explicitly call slotInitialize() so that the columns are added before
+    // SharedSettings::apply() sets the visible and hidden ones.
+    slotInitialize();
 }
 
 void Playlist::loadFile(const QString &fileName, const QFileInfo &fileInfo)
@@ -1827,11 +1822,22 @@ void Playlist::calculateColumnWeights()
 
     foreach(PlaylistItem *item, l) {
         cachedWidth = item->cachedWidths();
-        foreach(int column, m_weightDirty)
-            averageWidth[column] += std::pow(double(cachedWidth[column]), 2.0) / itemCount;
+
+        // Extra columns start at 0, but those weights aren't shared with all
+        // items.
+        for(int i = 0; i < columnOffset(); ++i) {
+            averageWidth[i] +=
+                std::pow(double(item->width(fontMetrics(), this, i)), 2.0) / itemCount;
+        }
+
+        for(int column = columnOffset(); column < columns(); ++column) {
+            averageWidth[column] +=
+                std::pow(double(cachedWidth[column - columnOffset()]), 2.0) / itemCount;
+        }
     }
 
-    m_columnWeights.fill(-1, columns());
+    if(m_columnWeights.isEmpty())
+        m_columnWeights.fill(-1, columns());
 
     foreach(int column, m_weightDirty) {
         m_columnWeights[column] = int(std::sqrt(averageWidth[column]) + 0.5);
@@ -1874,7 +1880,7 @@ void Playlist::addFile(const QString &file, FileHandleList &files, bool importPl
     }
 
     if(importPlaylists && MediaFiles::isPlaylistFile(file) &&
-       !m_collection->containsPlaylistFile(fileInfo.absoluteFilePath()))
+       !m_collection->containsPlaylistFile(fileInfo.canonicalFilePath()))
     {
         new Playlist(m_collection, fileInfo);
         return;
@@ -2330,7 +2336,9 @@ void Playlist::slotToggleColumnVisible(QAction *action)
     else
         showColumn(column);
 
-    SharedSettings::instance()->toggleColumnVisible(column - columnOffset());
+    if(column >= columnOffset()) {
+        SharedSettings::instance()->toggleColumnVisible(column - columnOffset());
+    }
 }
 
 void Playlist::slotCreateGroup()
