@@ -184,9 +184,11 @@ void PlaylistCollection::createDynamicPlaylist(const PlaylistList &playlists)
 {
     if(m_dynamicPlaylist)
         m_dynamicPlaylist->setPlaylists(playlists);
-    else
+    else {
         m_dynamicPlaylist =
             new DynamicPlaylist(playlists, this, i18n("Dynamic List"), "audio-midi", false, true);
+        PlaylistCollection::setupPlaylist(m_dynamicPlaylist, QString());
+    }
 
     PlaylistCollection::raise(m_dynamicPlaylist);
 }
@@ -205,6 +207,7 @@ void PlaylistCollection::showMore(const QString &artist, const QString &album)
 
     playlists.append(CollectionList::instance());
 
+    if(!artist.isNull())
     { // Just setting off the artist stuff in its own block.
         ColumnList columns;
         columns.append(PlaylistItem::ArtistColumn);
@@ -720,12 +723,12 @@ void PlaylistCollection::enableDirWatch(bool enable)
 
     m_dirLister.disconnect(object());
     if(enable) {
-        QObject::connect(&m_dirLister, SIGNAL(newItems(const KFileItemList &)),
-                object(), SLOT(slotNewItems(const KFileItemList &)));
-        QObject::connect(&m_dirLister, SIGNAL(refreshItems(const QList<QPair<KFileItem, KFileItem> > &)),
-                collection, SLOT(slotRefreshItems(const QList<QPair<KFileItem, KFileItem> > &)));
-        QObject::connect(&m_dirLister, SIGNAL(deleteItem(const KFileItem &)),
-                collection, SLOT(slotDeleteItem(const KFileItem &)));
+        QObject::connect(&m_dirLister, SIGNAL(newItems(KFileItemList)),
+                object(), SLOT(slotNewItems(KFileItemList)));
+        QObject::connect(&m_dirLister, SIGNAL(refreshItems(QList<QPair<KFileItem,KFileItem> >)),
+                collection, SLOT(slotRefreshItems(QList<QPair<KFileItem,KFileItem> >)));
+        QObject::connect(&m_dirLister, SIGNAL(deleteItem(KFileItem)),
+                collection, SLOT(slotDeleteItem(KFileItem)));
     }
 }
 
@@ -841,7 +844,7 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
     QObject(0),
     m_collection(collection)
 {
-    setObjectName("ActionHandler");
+    setObjectName( QLatin1String("ActionHandler" ));
 
     KActionMenu *menu;
 
