@@ -382,7 +382,7 @@ static void source_output_cb(pa_context *c, const pa_source_output_info *i, int
 
     /* NB Until Source Outputs support volumes, we just use the volume of the source itself */
     if (!captureDevices.contains(i->source)) {
-        kWarning(67100) << "Source Output refers to a Source we don't have any info for :s";
+        kDebug(67100) << "Source Output refers to a Source we don't have any info for (probably just a peak meter or similar)";
         return;
     }
 
@@ -892,9 +892,8 @@ Mixer_PULSE::Mixer_PULSE(Mixer *mixer, int devnum) : Mixer_Backend(mixer, devnum
         s_pulseActive = INACTIVE;
 
     // We require a glib event loop
-    QLatin1String dispatcher = QLatin1String(QAbstractEventDispatcher::instance()->metaObject()->className());
-    if ("QGuiEventDispatcherGlib" != dispatcher && "QEventDispatcherGlib" != dispatcher) {
-        kDebug(67100) << "Disabling PulseAudio integration for lack of GLib event loop: " << dispatcher;
+    if (!QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("EventDispatcherGlib")) {
+        kDebug(67100) << "Disabling PulseAudio integration for lack of GLib event loop";
         s_pulseActive = INACTIVE;
     }
 
